==> esm-3.0.0-py3-none-any.whl: esm-3.0.0.dist-info/LICENSE.md <==
# EvolutionaryScale Community License Agreement

Please read this EvolutionaryScale Community License Agreement (the “**Agreement**”) carefully before using the AI Model (as defined below), which is offered by EvolutionaryScale, PBC (“**ES**”).

By downloading the AI Model, or otherwise using the AI Model in any manner, You agree that You have read and agree to be bound by the terms of this Agreement. If You are accessing the AI Model on behalf of an organization or entity, You represent and warrant that You are authorized to enter into this Agreement on that organization’s or entity’s behalf and bind them to the terms of this Agreement (in which case, the references to “**You**” and “**Your**” in this Agreement, except for in this sentence, refer to that organization or entity) and that such entity is a non-commercial organization (such as a university, non-profit organization, research institute or educational or governmental body). Use of the AI Model is expressly conditioned upon Your assent to all terms of this Agreement, to the exclusion of all other terms.

## Definitions.

In addition to other terms defined elsewhere in this Agreement, the terms below have the following meanings.

1. “**AI Model**” means the EvolutionaryScale ESM-3 Open Model code and model weights made available at the following link [https://github.com/evolutionaryscale/esm] (the “**GitHub Page**”), as may be updated and amended from time to time, whether in Source or Object form, made available to You pursuant to this Agreement.
2. “**Commercial Entity**” means any entity engaged in any activity intended for or directed toward commercial advantage or monetary compensation, including, without limitation, the development of any product or service intended to be sold or made available for a fee. For the purpose of this Agreement, references to a Commercial Entity expressly exclude any universities, non-profit organizations, not-for-profit entities, research institutes and educational and government bodies.
3. “**Contribution**” means any work of authorship, including the original version of the AI Model and any modifications or additions to that AI Model or Derivative Works thereof, that is intentionally submitted to ES for inclusion in the AI Model by the copyright owner or by an individual or Legal Entity authorized to submit on behalf of the copyright owner. For the purposes of this definition, "**submitted**" means any form of electronic, verbal, or written communication sent to ES or its representatives, including but not limited to communication on electronic mailing lists, source code control systems, and issue tracking systems that are managed by, or on behalf of, ES for the purpose of discussing and improving the AI Model, but excluding Outputs and all communications that are conspicuously marked or otherwise designated in writing by the copyright owner as "**Not a Contribution**."
4. “**Contributor**” means ES and any individual or Legal Entity on behalf of whom a Contribution has been received by ES and subsequently incorporated within the AI Model.
5. “**Derivative Work**” means any work, whether in Source or Object form, that is based on (or derived from) the AI Model and for which the editorial revisions, annotations, elaborations, or other modifications represent, as a whole, an original work of authorship. For the purposes of this Agreement, Derivative Works shall not include works that remain separable from, or merely link (or bind by name) to the interfaces of, the AI Model and Derivative Works thereof.
6. “**Legal Entity**” means the union of the acting entity and all other entities that control, are controlled by, or are under common control with that entity. For the purposes of this definition, "**control**" means (i) the power, direct or indirect, to cause the direction or management of such entity, whether by contract or otherwise, or (ii) ownership of fifty percent (50%) or more of the outstanding shares, or (iii) beneficial ownership of such entity.
7. “**Non-Commercial Purposes**” means uses not intended for or directed toward commercial advantage or monetary compensation, or the facilitation of development of any product or service to be sold or made available for a fee. For the avoidance of doubt, the provision of Outputs as a service is not a Non-Commercial Purpose.
8. “**Object**” means any form resulting from mechanical transformation or translation of a Source form, including but not limited to compiled object code, generated documentation, and conversions to other media types.
9. “**Output**” means any output, including any protein sequence, structure prediction, functional annotation, molecule, descriptions of a molecule, model, sequence, text, and/or image that is elicited directly or indirectly by, or otherwise made available to, You in connection with Your use of the AI Model, including, but not limited to, the use of AI-Powered Technology.
10. “**Output Derivatives**” means any enhancements, modifications and derivative works of Outputs (including, but not limited to, any derivative sequences or molecules).
11. “**Source**” means the preferred form for making modifications, including but not limited to AI Model source code, documentation source, and configuration files.
12. “**Third Party Model**” means any non-human tool, platform and/or other technology powered or made available in connection with the use of generative artificial intelligence or machine learning models that is operated by any third party.
13. “**You**” or “**Your**” means the individual entering into this Agreement or the organization or entity on whose behalf such individual is entering into this Agreement.

## Intellectual Property Rights and Licenses.

1. **Copyright License. Subject to the terms and conditions of this Agreement, each Contributor hereby grants to You a non-exclusive, non-transferable, limited copyright license to reproduce, prepare Derivative Works of, publicly display, publicly perform, sublicense, and distribute the AI Model and such Derivative Works in Source or Object form for Your Non-Commercial Purposes.**
2. **Patent License**. Subject to the terms and conditions of this Agreement, each Contributor hereby grants to You a non-exclusive, non-transferable, limited patent license to make, have made, use, import, and otherwise transfer the AI Model for Your Non-Commercial Purposes, where such license applies only to those patent claims licensable by such Contributor that are necessarily infringed by their Contribution(s) alone or by combination of their Contribution(s) with the AI Model to which such Contribution(s) was submitted. If You institute patent litigation against any entity (including a cross-claim or counterclaim in a lawsuit) alleging that the AI Model or a Contribution incorporated within the AI Model constitutes direct or contributory patent infringement, then any patent licenses granted to You under this Agreement for that AI Model shall terminate as of the date such litigation is filed.

## Licensing Process.

In connection with Your licensing of the AI Model, ES may collect, from You or automatically through Your use of the AI Model, certain registration information about You, any Legal Entity You may represent, and Your use of the AI Model. The collection of this information and ES’s policies and procedures regarding the collection, use, disclosure and security of information received are described further in ES’s Privacy Policy available at [[](https://redpanda.com/legal/privacy-policy/)https://evolutionaryscale.ai/privacy], as may be updated from time to time.

## Redistribution.

Subject to Section 5 (Use Restrictions) below, You may reproduce and distribute copies of the AI Model or Derivative Works thereof in any medium, with or without modifications, and in Source or Object form for Your Non-Commercial Purposes, provided that You meet the following conditions:

1. You must not distribute copies of the AI Model or Derivative Works thereof to, or allow the use of any reproductions or copies thereof by, on behalf of or for, any Commercial Entity; and
2. You must restrict the usage of any copies of the AI Model or Derivative Works to usage for Non-Commercial Purposes; and
3. You must give any other recipients of the AI Model or Derivative Works a copy of this Agreement; and
4. You must cause any modified files to carry prominent notices stating that You changed the files; and
5. You must retain, in the Source form of any Derivative Works that You distribute, all copyright, patent, trademark, and attribution notices from the Source form of the AI Model, excluding those notices that do not pertain to any part of the Derivative Works; and
6. If the AI Model includes a "NOTICE" text file as part of its distribution, then any Derivative Works that You distribute must include a readable copy of the attribution notices contained within such NOTICE file, excluding those notices that do not pertain to any part of the Derivative Works, in at least one of the following places: within a NOTICE text file distributed as part of the Derivative Works; within the Source form or documentation, if provided along with the Derivative Works; or, within a display generated by the Derivative Works, if and wherever such third-party notices normally appear. The contents of the NOTICE file are for informational purposes only and do not modify this Agreement. You may add Your own attribution notices within Derivative Works that You distribute, alongside or as an addendum to the NOTICE text from the AI Model, provided that such additional attribution notices cannot be construed as modifying this Agreement.

You may add Your own copyright statement to Your modifications and may provide additional or different license terms and conditions for use, reproduction, or distribution of Your modifications, or for any such Derivative Works as a whole, provided Your use, reproduction, and distribution of the AI Model otherwise complies with the conditions stated in this Agreement.

## Use Restrictions.

**No Commercial Use**.  You may only use the AI Model, Contributions, Derivative Works, Outputs and Output Derivatives (as defined below) for Non-Commercial Purposes. For the avoidance of doubt, structure tokens are also considered Outputs and may only be used for Non-Commercial Purposes. Any commercial use of any of the foregoing, including, without limitation, any use by, on behalf of or for any Commercial Entity or to facilitate the development of any product or service to be sold or made available for a fee, is strictly prohibited under this Agreement.

**No Use in Drug Development or Discovery**.  Without limiting the foregoing, You may not use the AI Model or any Contributions, Derivative Works, Outputs or Output Derivatives in or in connection with: (i) the development (at any stage) or discovery of any drug, medication or pharmaceutical of any kind; (ii) any molecular or biological target, hit or lead identification; (iii) drug candidate selection; or (iv) lead optimization.

**Use of Outputs**.  Notwithstanding anything to the contrary in this Agreement, You may not use or provide access to any Outputs or Output Derivatives to train, optimize, improve or otherwise influence the functionality or performance of any: (i) other large language model; (ii) technology for protein structure prediction; ****or (iii) other Third Party Model ****that is similar to the AI Model. You may, however, use the Outputs and Outputs Derivatives to train, optimize, improve or otherwise influence the functionality or performance of the AI Model itself and downstream Derivative Works thereof.

**Additional Restrictions**.  Your use of the AI Model may also be subject to additional use restrictions communicated to You through the AI Model or otherwise, including those set forth in the ES Acceptable Use Policy available at [https://evolutionaryscale.ai/acceptable-use-policy], as may be updated and amended from time to time (the “**AUP**”), the terms of which are incorporated herein by reference. In the event of any conflict between the terms of this Agreement and the terms of the AUP, the terms that are more restrictive of Your use of the AI Model, Derivative Works, Outputs and Output Derivatives, as applicable, shall govern and control.

## Submission of Contributions.

Unless You explicitly state otherwise, any Contribution intentionally submitted for inclusion in the AI Model by You to ES shall be under the terms and conditions of this Agreement, without any additional terms or conditions. Notwithstanding the above, nothing herein shall supersede or modify the terms of any separate license agreement you may have executed with ES regarding such Contributions.

## Trademarks.

This Agreement does not grant permission to use the trade names, trademarks, service marks, or product names of ES, except as required for reasonable and customary use in describing the origin of the AI Model and reproducing the content of the NOTICE file.

## Disclaimer of Warranty.

UNLESS REQUIRED BY APPLICABLE LAW OR OTHERWISE EXPRESSLY AGREED MUTUALLY AGREED UPON BY YOU AND ES IN WRITING, ES PROVIDES THE AI MODEL (AND EACH CONTRIBUTOR PROVIDES ITS CONTRIBUTIONS) ON AN "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING, WITHOUT LIMITATION, ANY WARRANTIES OR CONDITIONS OF TITLE, NON-INFRINGEMENT, MERCHANTABILITY, CORRECTNESS, RELIABILITY OR FITNESS FOR A PARTICULAR PURPOSE, ALL OF WHICH ARE HEREBY DISCLAIMED. YOU ARE SOLELY RESPONSIBLE FOR DETERMINING THE APPROPRIATENESS OF USING OR REDISTRIBUTING THE AI MODEL AND ASSUME ANY RISKS ASSOCIATED WITH YOUR EXERCISE OF PERMISSIONS UNDER THIS AGREEMENT.

## Limitation of Liability.

In no event and under no legal theory, whether in tort (including negligence), contract, or otherwise, unless required by applicable law (such as deliberate and grossly negligent acts) or agreed to in writing, shall any Contributor be liable to You for damages, including any direct, indirect, special, incidental, or consequential damages of any character arising as a result of this Agreement or out of the use or inability to use the AI Model (including but not limited to damages for loss of goodwill, work stoppage, computer failure or malfunction, or any and all other commercial damages or losses), even if such Contributor has been advised of the possibility of such damages.

## General.

1. **Entire Agreement**. This Agreement constitutes the entire agreement between You and ES relating to the subject matter hereof and supersedes all proposals, understandings, or discussions, whether written or oral, relating to the subject matter of this Agreement and all past dealing or industry custom. The failure of either party to enforce its rights under this Agreement at any time for any period shall not be construed as a waiver of such rights. ES may amend or modify this Agreement from time to time and will use reasonable efforts to provide You with notice of any material changes that may negatively impact Your use of the AI Model through the GitHub Page or through another means made available to You. No other changes, modifications or waivers to this Agreement will be effective unless in writing and signed by both parties.
2. **Relationship of Parties**. You and ES are independent contractors, and nothing herein shall be deemed to constitute either party as the agent or representative of the other or both parties as joint venturers or partners for any purpose.
3. **Export Control**. You shall comply with the U.S. Foreign Corrupt Practices Act and all applicable export laws, restrictions and regulations of the U.S. Department of Commerce, and any other applicable U.S. and foreign authority.
4. **Assignment**. This Agreement and the rights and obligations herein may not be assigned or transferred, in whole or in part, by You without the prior written consent of ES. Any assignment in violation of this provision is void. ES may freely assign or transfer this Agreement, in whole or in part. This Agreement shall be binding upon, and inure to the benefit of, the successors and permitted assigns of the parties.
5. **Governing Law**. This Agreement shall be governed by and construed under the laws of the State of New York and the United States without regard to conflicts of laws provisions thereof, and without regard to the Uniform Computer Information Transactions Act.
6. **Severability**.  If any provision of this Agreement is held to be invalid, illegal or unenforceable in any respect, that provision shall be limited or eliminated to the minimum extent necessary so that this Agreement otherwise remains in full force and effect and enforceable.

==> esm-3.0.5-py3-none-any.whl: esm-3.0.5.dist-info/LICENSE.md <==
# EvolutionaryScale Community License Agreement

This license is a reproduction of the EvolutionaryScale Community License Agreement available at <https://www.evolutionaryscale.ai/policies/community-license-agreement>.

Please read this EvolutionaryScale Community License Agreement (the “**Agreement**”) carefully before using the AI Model (as defined below), which is offered by EvolutionaryScale, PBC (“**ES**”).

By downloading the AI Model, or otherwise using the AI Model in any manner, You agree that You have read and agree to be bound by the terms of this Agreement. If You are accessing the AI Model on behalf of an organization or entity, You represent and warrant that You are authorized to enter into this Agreement on that organization’s or entity’s behalf and bind them to the terms of this Agreement (in which case, the references to “**You**” and “**Your**” in this Agreement, except for in this sentence, refer to that organization or entity) and that such entity is a non-commercial organization (such as a university, non-profit organization, research institute or educational or governmental body). Use of the AI Model is expressly conditioned upon Your assent to all terms of this Agreement, to the exclusion of all other terms.

## Definitions.

In addition to other terms defined elsewhere in this Agreement, the terms below have the following meanings.

1. “**AI Model**” means the EvolutionaryScale ESM-3 Open Model code and model weights made available at the following link [https://github.com/evolutionaryscale/esm] (the “**GitHub Page**”), as may be updated and amended from time to time, whether in Source or Object form, made available to You pursuant to this Agreement.
2. “**Commercial Entity**” means any entity engaged in any activity intended for or directed toward commercial advantage or monetary compensation, including, without limitation, the development of any product or service intended to be sold or made available for a fee. For the purpose of this Agreement, references to a Commercial Entity expressly exclude any universities, non-profit organizations, not-for-profit entities, research institutes and educational and government bodies.
3. “**Contribution**” means any work of authorship, including the original version of the AI Model and any modifications or additions to that AI Model or Derivative Works thereof, that is intentionally submitted to ES for inclusion in the AI Model by the copyright owner or by an individual or Legal Entity authorized to submit on behalf of the copyright owner. For the purposes of this definition, "**submitted**" means any form of electronic, verbal, or written communication sent to ES or its representatives, including but not limited to communication on electronic mailing lists, source code control systems, and issue tracking systems that are managed by, or on behalf of, ES for the purpose of discussing and improving the AI Model, but excluding Outputs and all communications that are conspicuously marked or otherwise designated in writing by the copyright owner as "**Not a Contribution**."
4. “**Contributor**” means ES and any individual or Legal Entity on behalf of whom a Contribution has been received by ES and subsequently incorporated within the AI Model.
5. “**Derivative Work**” means any work, whether in Source or Object form, that is based on (or derived from) the AI Model and for which the editorial revisions, annotations, elaborations, or other modifications represent, as a whole, an original work of authorship. For the purposes of this Agreement, Derivative Works shall not include works that remain separable from, or merely link (or bind by name) to the interfaces of, the AI Model and Derivative Works thereof.
6. “**Legal Entity**” means the union of the acting entity and all other entities that control, are controlled by, or are under common control with that entity. For the purposes of this definition, "**control**" means (i) the power, direct or indirect, to cause the direction or management of such entity, whether by contract or otherwise, or (ii) ownership of fifty percent (50%) or more of the outstanding shares, or (iii) beneficial ownership of such entity.
7. “**Non-Commercial Purposes**” means uses not intended for or directed toward commercial advantage or monetary compensation, or the facilitation of development of any product or service to be sold or made available for a fee. For the avoidance of doubt, the provision of Outputs as a service is not a Non-Commercial Purpose.
8. “**Object**” means any form resulting from mechanical transformation or translation of a Source form, including but not limited to compiled object code, generated documentation, and conversions to other media types.
9. “**Output**” means any output, including any protein sequence, structure prediction, functional annotation, molecule, descriptions of a molecule, model, sequence, text, and/or image that is elicited directly or indirectly by, or otherwise made available to, You in connection with Your use of the AI Model, including, but not limited to, the use of AI-Powered Technology.
10. “**Output Derivatives**” means any enhancements, modifications and derivative works of Outputs (including, but not limited to, any derivative sequences or molecules).
11. “**Source**” means the preferred form for making modifications, including but not limited to AI Model source code, documentation source, and configuration files.
12. “**Third Party Model**” means any non-human tool, platform and/or other technology powered or made available in connection with the use of generative artificial intelligence or machine learning models that is operated by any third party.
13. “**You**” or “**Your**” means the individual entering into this Agreement or the organization or entity on whose behalf such individual is entering into this Agreement.

## Intellectual Property Rights and Licenses.

1. **Copyright License. Subject to the terms and conditions of this Agreement, each Contributor hereby grants to You a non-exclusive, non-transferable, limited copyright license to reproduce, prepare Derivative Works of, publicly display, publicly perform, sublicense, and distribute the AI Model and such Derivative Works in Source or Object form for Your Non-Commercial Purposes.**
2. **Patent License**. Subject to the terms and conditions of this Agreement, each Contributor hereby grants to You a non-exclusive, non-transferable, limited patent license to make, have made, use, import, and otherwise transfer the AI Model for Your Non-Commercial Purposes, where such license applies only to those patent claims licensable by such Contributor that are necessarily infringed by their Contribution(s) alone or by combination of their Contribution(s) with the AI Model to which such Contribution(s) was submitted. If You institute patent litigation against any entity (including a cross-claim or counterclaim in a lawsuit) alleging that the AI Model or a Contribution incorporated within the AI Model constitutes direct or contributory patent infringement, then any patent licenses granted to You under this Agreement for that AI Model shall terminate as of the date such litigation is filed.

## Licensing Process.

In connection with Your licensing of the AI Model, ES may collect, from You or automatically through Your use of the AI Model, certain registration information about You, any Legal Entity You may represent, and Your use of the AI Model. The collection of this information and ES’s policies and procedures regarding the collection, use, disclosure and security of information received are described further in ES’s Privacy Policy available at <https://evolutionaryscale.ai/policies/privacy>, as may be updated from time to time.

## Redistribution.

Subject to Section 5 (Use Restrictions) below, You may reproduce and distribute copies of the AI Model or Derivative Works thereof in any medium, with or without modifications, and in Source or Object form for Your Non-Commercial Purposes, provided that You meet the following conditions:

1. You must not distribute copies of the AI Model or Derivative Works thereof to, or allow the use of any reproductions or copies thereof by, on behalf of or for, any Commercial Entity; and
2. You must restrict the usage of any copies of the AI Model or Derivative Works to usage for Non-Commercial Purposes; and
3. You must give any other recipients of the AI Model or Derivative Works a copy of this Agreement; and
4. You must cause any modified files to carry prominent notices stating that You changed the files; and
5. You must retain, in the Source form of any Derivative Works that You distribute, all copyright, patent, trademark, and attribution notices from the Source form of the AI Model, excluding those notices that do not pertain to any part of the Derivative Works; and
6. If the AI Model includes a "NOTICE" text file as part of its distribution, then any Derivative Works that You distribute must include a readable copy of the attribution notices contained within such NOTICE file, excluding those notices that do not pertain to any part of the Derivative Works, in at least one of the following places: within a NOTICE text file distributed as part of the Derivative Works; within the Source form or documentation, if provided along with the Derivative Works; or, within a display generated by the Derivative Works, if and wherever such third-party notices normally appear. The contents of the NOTICE file are for informational purposes only and do not modify this Agreement. You may add Your own attribution notices within Derivative Works that You distribute, alongside or as an addendum to the NOTICE text from the AI Model, provided that such additional attribution notices cannot be construed as modifying this Agreement.

You may add Your own copyright statement to Your modifications and may provide additional or different license terms and conditions for use, reproduction, or distribution of Your modifications, or for any such Derivative Works as a whole, provided Your use, reproduction, and distribution of the AI Model otherwise complies with the conditions stated in this Agreement.

## Use Restrictions.

**No Commercial Use**.  You may only use the AI Model, Contributions, Derivative Works, Outputs and Output Derivatives (as defined below) for Non-Commercial Purposes. For the avoidance of doubt, structure tokens are also considered Outputs and may only be used for Non-Commercial Purposes. Any commercial use of any of the foregoing, including, without limitation, any use by, on behalf of or for any Commercial Entity or to facilitate the development of any product or service to be sold or made available for a fee, is strictly prohibited under this Agreement.

**No Use in Drug Development or Discovery**.  Without limiting the foregoing, You may not use the AI Model or any Contributions, Derivative Works, Outputs or Output Derivatives in or in connection with: (i) the development (at any stage) or discovery of any drug, medication or pharmaceutical of any kind; (ii) any molecular or biological target, hit or lead identification; (iii) drug candidate selection; or (iv) lead optimization.

**Use of Outputs**.  Notwithstanding anything to the contrary in this Agreement, You may not use or provide access to any Outputs or Output Derivatives to train, optimize, improve or otherwise influence the functionality or performance of any: (i) other large language model; (ii) technology for protein structure prediction; ****or (iii) other Third Party Model ****that is similar to the AI Model. You may, however, use the Outputs and Outputs Derivatives to train, optimize, improve or otherwise influence the functionality or performance of the AI Model itself and downstream Derivative Works thereof.

**Additional Restrictions**.  Your use of the AI Model may also be subject to additional use restrictions communicated to You through the AI Model or otherwise, including those set forth in the ES Acceptable Use Policy available at <https://evolutionaryscale.ai/policies/acceptable-use-policy>, as may be updated and amended from time to time (the “**AUP**”), the terms of which are incorporated herein by reference. In the event of any conflict between the terms of this Agreement and the terms of the AUP, the terms that are more restrictive of Your use of the AI Model, Derivative Works, Outputs and Output Derivatives, as applicable, shall govern and control.

## Submission of Contributions.

Unless You explicitly state otherwise, any Contribution intentionally submitted for inclusion in the AI Model by You to ES shall be under the terms and conditions of this Agreement, without any additional terms or conditions. Notwithstanding the above, nothing herein shall supersede or modify the terms of any separate license agreement you may have executed with ES regarding such Contributions.

## Trademarks.

This Agreement does not grant permission to use the trade names, trademarks, service marks, or product names of ES, except as required for reasonable and customary use in describing the origin of the AI Model and reproducing the content of the NOTICE file.

## Disclaimer of Warranty.

UNLESS REQUIRED BY APPLICABLE LAW OR OTHERWISE EXPRESSLY AGREED MUTUALLY AGREED UPON BY YOU AND ES IN WRITING, ES PROVIDES THE AI MODEL (AND EACH CONTRIBUTOR PROVIDES ITS CONTRIBUTIONS) ON AN "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING, WITHOUT LIMITATION, ANY WARRANTIES OR CONDITIONS OF TITLE, NON-INFRINGEMENT, MERCHANTABILITY, CORRECTNESS, RELIABILITY OR FITNESS FOR A PARTICULAR PURPOSE, ALL OF WHICH ARE HEREBY DISCLAIMED. YOU ARE SOLELY RESPONSIBLE FOR DETERMINING THE APPROPRIATENESS OF USING OR REDISTRIBUTING THE AI MODEL AND ASSUME ANY RISKS ASSOCIATED WITH YOUR EXERCISE OF PERMISSIONS UNDER THIS AGREEMENT.

## Limitation of Liability.

In no event and under no legal theory, whether in tort (including negligence), contract, or otherwise, unless required by applicable law (such as deliberate and grossly negligent acts) or agreed to in writing, shall any Contributor be liable to You for damages, including any direct, indirect, special, incidental, or consequential damages of any character arising as a result of this Agreement or out of the use or inability to use the AI Model (including but not limited to damages for loss of goodwill, work stoppage, computer failure or malfunction, or any and all other commercial damages or losses), even if such Contributor has been advised of the possibility of such damages.

## General.

1. **Entire Agreement**. This Agreement constitutes the entire agreement between You and ES relating to the subject matter hereof and supersedes all proposals, understandings, or discussions, whether written or oral, relating to the subject matter of this Agreement and all past dealing or industry custom. The failure of either party to enforce its rights under this Agreement at any time for any period shall not be construed as a waiver of such rights. ES may amend or modify this Agreement from time to time and will use reasonable efforts to provide You with notice of any material changes that may negatively impact Your use of the AI Model through the GitHub Page or through another means made available to You. No other changes, modifications or waivers to this Agreement will be effective unless in writing and signed by both parties.
2. **Relationship of Parties**. You and ES are independent contractors, and nothing herein shall be deemed to constitute either party as the agent or representative of the other or both parties as joint venturers or partners for any purpose.
3. **Export Control**. You shall comply with the U.S. Foreign Corrupt Practices Act and all applicable export laws, restrictions and regulations of the U.S. Department of Commerce, and any other applicable U.S. and foreign authority.
4. **Assignment**. This Agreement and the rights and obligations herein may not be assigned or transferred, in whole or in part, by You without the prior written consent of ES. Any assignment in violation of this provision is void. ES may freely assign or transfer this Agreement, in whole or in part. This Agreement shall be binding upon, and inure to the benefit of, the successors and permitted assigns of the parties.
5. **Governing Law**. This Agreement shall be governed by and construed under the laws of the State of New York and the United States without regard to conflicts of laws provisions thereof, and without regard to the Uniform Computer Information Transactions Act.
6. **Severability**.  If any provision of this Agreement is held to be invalid, illegal or unenforceable in any respect, that provision shall be limited or eliminated to the minimum extent necessary so that this Agreement otherwise remains in full force and effect and enforceable.
